Module: Mince::HashyDb::Version
- Defined in:
- lib/hashy_db/version.rb
Overview
HashyDb Version
HashyDb Version specifies the version of this library
Use these versions to negotiate with for compatibility
Major version releases indicates a major enhancement, breaks backward compatibility Minor version release indicates an addition, enhancement or bug fix which is not an immediate need, does not break backward compatibility Patch version release indicates a bug fix or patch that is an emergency, does not break backward compatibility
Class Method Summary collapse
-
.major ⇒ Object
Provides the major level version of the library.
-
.minor ⇒ Object
Provides the minor level version of the library.
-
.patch ⇒ Object
Provides the patch level version of the library.
Class Method Details
.major ⇒ Object
Provides the major level version of the library
17 18 19 |
# File 'lib/hashy_db/version.rb', line 17 def self.major 2 end |
.minor ⇒ Object
Provides the minor level version of the library
22 23 24 |
# File 'lib/hashy_db/version.rb', line 22 def self.minor 1 end |
.patch ⇒ Object
Provides the patch level version of the library
27 28 29 |
# File 'lib/hashy_db/version.rb', line 27 def self.patch 0 end |